@@ -37,6 +37,10 @@ fields={'cuisine': ['American','Italian','Mexican',
         'source' : [],
         'category' : ['Dessert','Entree','Salad','Soup',
                       'Breakfast'],
+        'yield_unit':['servings','cups','pints','gallons','ounces',
+                      'cookies','crusts',
+                      ],
+        
                   }
 
 # In English, there are a heck of a lot of synonyms. This is a list
@@ -187,7 +191,7 @@ INGREDIENT_DATA = [["alfalfa sprouts","alfalfa sprouts","produce"],
                    ["red bell pepper","bell pepper, red","produce"],
                    ["chilli pepper","chilli pepper","produce"],
                    ["jalapeño pepper","pepper, jalapeño","produce"],
-                   ["habanero pepper","pepper, habanero","produce"],
+                   ["habañero pepper","pepper, habañero","produce"],
                    ["radicchio","radicchio","produce"],
                    ["rapini","rapini","produce"],
                    ["rhubarb","rhubarb","produce"],
@@ -817,3 +821,17 @@ NUMBERS = {
     50:['fifty'],
     60:['sixty'],
     }
+
+PLURALS = [
+    ('loaf','loaves'),
+    ('box','boxes'),
+    ]
+
+PLURALS += [(s,s+'s') for s in
+                       ['cup','crust','clove','serving','pound','gram',
+                        'ounce','tablespoon','teaspoon','gallon','can',
+                        'slice','pie','package','quart','pint','muffin',
+                        'cookie',]
+                       ]
+
+        
