@@ -211,6 +211,11 @@ class exporter (SuspendableThread, Pluggable):
                     ret = "%s/5 %s"%(ret/2.0,_('stars'))
             elif attr=='servings' and type(ret)!=str:
                 ret = convert.float_to_frac(ret,fractions=self.fractions)
+            elif attr=='yields':
+                ret = convert.float_to_frac(ret,fractions=self.fractions)
+                yield_unit = self._grab_attr_(obj,'yield_unit')
+                if yield_unit:
+                    ret = '%s %s'%(ret,yield_unit) # FIXME: i18n? (fix also below in exporter_mult)
             if type(ret) in [str,unicode] and attr not in ['thumb','image']:
                 try:
                     ret = ret.encode(self.DEFAULT_ENCODING)
@@ -293,6 +298,9 @@ class exporter (SuspendableThread, Pluggable):
 
     def handle_markup (self, txt):
         """Handle markup inside of txt."""
+        if txt == None:
+            print 'Warning, handle_markup handed None'
+            return ''
         import pango
         outtxt = ""
         try:
@@ -416,7 +424,7 @@ class exporter_mult (exporter):
         Possibly manipulate the attribute we get to hand out export
         something readable.
         """        
-        if attr=='servings' and self.mult:
+        if attr=='servings' or attr=='yields' and self.mult:
             ret = getattr(obj,attr)
             if type(ret) in [int,float]:
                 fl_ret = float(ret)
@@ -425,8 +433,13 @@ class exporter_mult (exporter):
                     print 'WARNING: IGNORING serving value ',ret
                 fl_ret = None
             if fl_ret:
-                return convert.float_to_frac(fl_ret * self.mult,
-                                             fractions=self.fractions)
+                ret = convert.float_to_frac(fl_ret * self.mult,
+                                            fractions=self.fractions)
+                if attr=='yields' :
+                    yield_unit = self._grab_attr_(obj,'yield_unit')
+                    if yield_unit:
+                        ret = '%s %s'%(ret,yield_unit) # FIXME: i18n?
+                return ret
         else:
             return exporter._grab_attr_(self,obj,attr)
 
@@ -454,7 +467,7 @@ class ExporterMultirec (SuspendableThread, Pluggable):
 
     name = 'Exporter'
 
-    def __init__ (self, rd, recipe_table, out, one_file=True,
+    def __init__ (self, rd, recipes, out, one_file=True,
                   ext='txt',
                   conv=None,
                   imgcount=1,
@@ -462,13 +475,13 @@ class ExporterMultirec (SuspendableThread, Pluggable):
                   exporter=exporter,
                   exporter_kwargs={},
                   padding=None):
-        """Output all recipes in recipe_table into a document or multiple
+        """Output all recipes in recipes into a document or multiple
         documents. if one_file, then everything is in one
         file. Otherwise, we treat 'out' as a directory and put
         individual recipe files within it."""
         self.timer=TimeAction('exporterMultirec.__init__()')
         self.rd = rd
-        self.recipe_table = recipe_table
+        self.recipes = recipes
         self.out = out
         self.padding=padding
         self.one_file = one_file
@@ -509,12 +522,22 @@ class ExporterMultirec (SuspendableThread, Pluggable):
                     print "oops:",ret,"doesn't look like unicode."
                     raise
             return ret
+
+    def append_referenced_recipes (self):
+        for r in self.recipes[:]:
+            reffed = self.rd.db.execute(
+                'select * from ingredients where recipe_id=? and refid is not null',r.id
+                )
+            for ref in reffed:
+                rec = self.rd.get_rec(ref.refid)
+                if not rec in self.recipes:
+                    print 'Appending recipe ',rec.title,'referenced in ',r.title
+                    self.recipes.append(rec)
         
     @pluggable_method
     def do_run (self):
-        print 'Exportermultirec.do_run'
         self.rcount = 0
-        self.rlen = len(self.recipe_table)        
+        self.rlen = len(self.recipes)        
         if not self.one_file:
             self.outdir=self.out
             if os.path.exists(self.outdir):
@@ -529,7 +552,8 @@ class ExporterMultirec (SuspendableThread, Pluggable):
         self.suspended = False
         self.terminated = False
         first = True
-        for r in self.recipe_table:
+        self.append_referenced_recipes()
+        for r in self.recipes:
             self.check_for_sleep()
             msg = _("Exported %(number)s of %(total)s recipes")%{'number':self.rcount,'total':self.rlen}
             self.emit('progress',float(self.rcount)/float(self.rlen), msg)
